@@ -108,6 +108,9 @@ class ScpiTransportBase(IO):
                  traceback) -> Optional[bool]:
         return self.io.__exit__(t, value, traceback)
 
+    def __del__(self):
+        del self.io
+        del self.logger
 
 # TypeVar for type hinting subclasses of ScpiTransportBase
 ScpiTransports = TypeVar('ScpiTransports', bound=ScpiTransportBase)
